@@ -73,7 +73,7 @@ void Core::Menu_File_Open_Files_Begin (bool Close, bool WithThread)
 size_t Core::Menu_File_Open_Files_Continue (const String &FileName)
 {
     /*
-    //Initilaizing MediaInfo
+    //Initializing MediaInfo
     MediaInfo MI;
 
     //From: preparing an example file for reading
@@ -249,8 +249,28 @@ void Core::Menu_View_PBCore2 ()
 //---------------------------------------------------------------------------
 void Core::Menu_View_MPEG7 ()
 {
-    MI->Option(__T("Inform"), __T("MPEG-7"));
-    Kind=Kind_MPEG7;
+    Menu_View_MPEG7_Relaxed();
+}
+
+//---------------------------------------------------------------------------
+void Core::Menu_View_MPEG7_Strict ()
+{
+    MI->Option(__T("Inform"), __T("MPEG-7_Strict"));
+    Kind=Kind_MPEG7_Strict;
+}
+
+//---------------------------------------------------------------------------
+void Core::Menu_View_MPEG7_Relaxed()
+{
+    MI->Option(__T("Inform"), __T("MPEG-7_Relaxed"));
+    Kind = Kind_MPEG7_Relaxed;
+}
+
+//---------------------------------------------------------------------------
+void Core::Menu_View_MPEG7_Extended()
+{
+    MI->Option(__T("Inform"), __T("MPEG-7_Extended"));
+    Kind = Kind_MPEG7_Extended;
 }
 
 //---------------------------------------------------------------------------
@@ -330,6 +350,13 @@ void Core::Menu_View_NISO_Z39_87()
     Kind = Kind_NISO_Z39_87;
 }
 
+//---------------------------------------------------------------------------
+void Core::Menu_View_Graph_Adm_Svg()
+{
+    MI->Option(__T("Inform"), __T("Graph_Adm_Svg"));
+    Kind = Kind_Graph_Adm_Svg;
+}
+
 //---------------------------------------------------------------------------
 void Core::Menu_Option_Preferences_Inform (const String& Inform)
 {
@@ -464,22 +491,14 @@ String Core::Get (size_t FilePos, stream_t StreamKind, size_t StreamNumber, cons
 String Core::StreamName (stream_t StreamKind) {
     switch(StreamKind) {
     case Stream_General: return __T("General");
-        break;
-    case Stream_Audio: return __T("Audio");
-        break;
-    case Stream_Video: return __T("Video");
-        break;
-    case Stream_Text: return __T("Text");
-        break;
-    case Stream_Other: return __T("Other");
-        break;
-    case Stream_Image: return __T("Image");
-        break;
-    case Stream_Menu: return __T("Menu");
-        break;
-    default: return __T("Unknown stream");
-        break;
-    }
+	case Stream_Audio: return __T("Audio");
+	case Stream_Video: return __T("Video");
+	case Stream_Text: return __T("Text");
+	case Stream_Other: return __T("Other");
+	case Stream_Image: return __T("Image");
+	case Stream_Menu: return __T("Menu");
+	default: return __T("Unknown stream");
+	}
 }
 
 String Core::Parameters () {
