@@ -32,7 +32,7 @@
 //---------------------------------------------------------------------------
 
 //---------------------------------------------------------------------------
-#define MediaInfo_Version_GUI __T("23.10")
+#define MediaInfo_Version_GUI __T("24.01.1")
 //---------------------------------------------------------------------------
 
 //---------------------------------------------------------------------------
@@ -96,6 +96,8 @@ public:
     //Plugins
     ZenLib::Ztring GraphPluginURL;
     ZenLib::Ztring GraphPluginVersion;
+    ZenLib::Ztring FFmpegPluginURL;
+    ZenLib::Ztring FFmpegPluginVersion;
 };
 
 //General preference for the whole program
