@@ -12,8 +12,7 @@ import java.io.File
 
 import androidx.appcompat.app.AppCompatActivity
 import androidx.recyclerview.widget.RecyclerView
-import androidx.lifecycle.ViewModelProviders
-import androidx.lifecycle.Observer
+import androidx.lifecycle.ViewModelProvider
 import androidx.core.app.ActivityCompat
 import androidx.appcompat.app.AppCompatDelegate
 
@@ -33,19 +32,14 @@ import android.content.Context
 import android.widget.Toast
 import android.content.SharedPreferences
 import android.content.pm.PackageManager
+import android.content.res.Configuration
 import android.content.res.Resources
 import android.view.*
 import androidx.preference.PreferenceManager.getDefaultSharedPreferences
-
 import io.reactivex.disposables.CompositeDisposable
 import io.reactivex.schedulers.Schedulers
 import io.reactivex.android.schedulers.AndroidSchedulers
 
-import kotlinx.android.synthetic.main.activity_report_list.*
-import kotlinx.android.synthetic.main.report_list_content.view.*
-import kotlinx.android.synthetic.main.report_list.*
-import kotlinx.android.synthetic.main.hello_layout.*
-
 import com.github.angads25.filepicker.model.DialogConfigs
 import com.github.angads25.filepicker.model.DialogProperties
 import com.github.angads25.filepicker.view.FilePickerDialog
@@ -53,6 +47,10 @@ import com.yariksoffice.lingver.Lingver
 import java.io.BufferedReader
 import java.util.*
 
+import  net.mediaarea.mediainfo.databinding.ActivityReportListBinding
+import  net.mediaarea.mediainfo.databinding.ReportListContentBinding
+import  net.mediaarea.mediainfo.databinding.HelloLayoutBinding
+
 /**
  * An activity representing a list of Pings. This activity
  * has different presentations for handset and tablet-size devices. On
@@ -62,6 +60,8 @@ import java.util.*
  * item details side-by-side using two vertical panes.
  */
 class ReportListActivity : AppCompatActivity(), ReportActivityListener {
+    private lateinit var activityReportListBinding: ActivityReportListBinding
+    private lateinit var helloLayoutBinding: HelloLayoutBinding
     private lateinit var subscriptionManager: SubscriptionManager
     private lateinit var reportModel: ReportViewModel
     private var disposable: CompositeDisposable = CompositeDisposable()
@@ -73,9 +73,8 @@ class ReportListActivity : AppCompatActivity(), ReportActivityListener {
         override fun onPreExecute() {
             super.onPreExecute()
 
-            add_button.hide()
-
-            val rootLayout: FrameLayout = findViewById(R.id.frame_layout)
+            activityReportListBinding.addButton.hide()
+            val rootLayout: FrameLayout = activityReportListBinding.frameLayout
             var found = false
             for (i: Int in rootLayout.childCount downTo 1) {
                 if (rootLayout.getChildAt(i - 1).id == R.id.spinner_layout)
@@ -89,9 +88,9 @@ class ReportListActivity : AppCompatActivity(), ReportActivityListener {
         override fun onPostExecute(result: Boolean?) {
             super.onPostExecute(result)
 
-            add_button.show()
+            activityReportListBinding.addButton.show()
 
-            val rootLayout: FrameLayout = findViewById(R.id.frame_layout)
+            val rootLayout: FrameLayout = activityReportListBinding.frameLayout
             for (i: Int in rootLayout.childCount downTo 1) {
                 if (rootLayout.getChildAt(i - 1).id == R.id.spinner_layout)
                     rootLayout.removeViewAt(i - 1)
@@ -115,7 +114,10 @@ class ReportListActivity : AppCompatActivity(), ReportActivityListener {
                                 // moveToFirst() returns false if the cursor has 0 rows
                                 if (cursor != null && cursor.moveToFirst()) {
                                     // DISPLAY_NAME is provider-specific, and might not be the file name
-                                    displayName = cursor.getString(cursor.getColumnIndex(OpenableColumns.DISPLAY_NAME))
+                                    val column = cursor.getColumnIndexOrThrow(OpenableColumns.DISPLAY_NAME)
+                                    if (column >= 0) {
+                                        displayName = cursor.getString(column)
+                                    }
                                     cursor.close()
                                 }
                             } catch (e: Exception) {
@@ -126,7 +128,7 @@ class ReportListActivity : AppCompatActivity(), ReportActivityListener {
                         }
                     }
                     "file" -> {
-                        val file = File(uri.path)
+                        val file = File(uri.path.orEmpty())
                         try {
                             fd = ParcelFileDescriptor.open(file, ParcelFileDescriptor.MODE_READ_ONLY)
                         } catch (e: Exception) {}
@@ -151,24 +153,7 @@ class ReportListActivity : AppCompatActivity(), ReportActivityListener {
                                         .subscribeOn(Schedulers.io())
                                         .observeOn(AndroidSchedulers.mainThread())
                                         .doOnSuccess {
-                                            val id: Int = it
-                                            if (twoPane) {
-                                                val fragment: ReportDetailFragment = ReportDetailFragment().apply {
-                                                    arguments = Bundle().apply {
-                                                        putInt(ReportDetailFragment.ARG_REPORT_ID, id)
-                                                    }
-                                                }
-
-                                                supportFragmentManager
-                                                        .beginTransaction()
-                                                        .replace(R.id.report_detail_container, fragment)
-                                                        .commit()
-                                            } else {
-                                                val intent = Intent(this@ReportListActivity, ReportDetailActivity::class.java)
-                                                intent.putExtra(ReportDetailFragment.ARG_REPORT_ID, id)
-
-                                                startActivity(intent)
-                                            }
+                                            showReport(it)
                                         }.subscribe())
                             }
                         }.subscribe())
@@ -178,6 +163,7 @@ class ReportListActivity : AppCompatActivity(), ReportActivityListener {
     }
 
     override fun onRequestPermissionsResult(requestCode: Int, permissions: Array<String>, grantResults: IntArray) {
+        super.onRequestPermissionsResult(requestCode, permissions, grantResults)
         when (requestCode) {
             READ_EXTERNAL_STORAGE_PERMISSION_REQUEST -> {
                 if ((grantResults.isNotEmpty() && grantResults[0] == PackageManager.PERMISSION_GRANTED)) {
@@ -191,6 +177,10 @@ class ReportListActivity : AppCompatActivity(), ReportActivityListener {
         }
     }
 
+    override fun onConfigurationChanged(newConfig: Configuration) {
+        super.onConfigurationChanged(newConfig)
+    }
+
     override fun onNewIntent(intent: Intent) {
         super.onNewIntent(intent)
         setIntent(intent)
@@ -214,66 +204,107 @@ class ReportListActivity : AppCompatActivity(), ReportActivityListener {
 
     private fun handleIntent(intent: Intent) {
         if (intent.action != null) {
-            val action: String? = intent.action
-            if (action == Intent.ACTION_VIEW) {
-                val uri: Uri? = intent.data
-                if (uri != null) {
-                    handleUri(uri)
+            if (intent.getBooleanExtra(OPEN_INTENT_PROCESSED, false)) {
+                return
+            }
+
+            when (intent.action) {
+                Intent.ACTION_VIEW -> {
+                    val uri: Uri? = intent.data
+                    if (uri != null) {
+                        handleUri(uri)
+                    }
+                    intent.putExtra(OPEN_INTENT_PROCESSED, true)
                 }
-            } else if (action == Intent.ACTION_SEND) {
-                val uri = intent.getParcelableExtra<Uri>(Intent.EXTRA_STREAM)
-                if (uri != null) {
-                    handleUri(uri)
-                } else if (action == Intent.ACTION_SEND_MULTIPLE) {
+                Intent.ACTION_SEND -> {
+                    val uri = intent.getParcelableExtra<Uri>(Intent.EXTRA_STREAM)
+                    if (uri != null) {
+                        handleUri(uri)
+                    }
+                    intent.putExtra(OPEN_INTENT_PROCESSED, true)
+                }
+                Intent.ACTION_SEND_MULTIPLE -> {
                     val uriList = intent.getParcelableArrayListExtra<Uri>(Intent.EXTRA_STREAM)
                     if (uriList != null) {
-                        for (uri in uriList) {
-                            handleUri(uri)
+                        for (i in uriList) {
+                            handleUri(i)
+                        }
+                    }
+                    intent.putExtra(OPEN_INTENT_PROCESSED, true)
+                }
+            }
+        }
+    }
+
+    private fun updatePreferences() {
+        val sharedPreferences = getDefaultSharedPreferences(this)
+        val key = getString(R.string.preferences_uimode_key)
+
+        when (sharedPreferences?.contains(key)) {
+            false, null -> {
+                val oldSharedPreferences = getSharedPreferences(getString(R.string.preferences_key), Context.MODE_PRIVATE)
+                if (oldSharedPreferences?.contains(key) == true) {
+                    oldSharedPreferences.getString(key, "").let {
+                        when (it) {
+                            "ON" -> {
+                                oldSharedPreferences.edit()?.remove(key)
+                                sharedPreferences.edit()?.putString(key, "on")?.apply()
+                            }
+                            "OFF" -> {
+                                oldSharedPreferences.edit()?.remove(key)
+                                sharedPreferences.edit()?.putString(key, "off")?.apply()
+
+                            }
+                            else -> {
+                            }
                         }
                     }
                 }
             }
+            true -> {
+                try {
+                    sharedPreferences.getBoolean(key, false).let {
+                        when (it) {
+                            false -> {
+                                sharedPreferences.edit()?.remove(key)
+                                sharedPreferences.edit()?.putString(key, "off")?.apply()
+                            }
+                            true -> {
+                                sharedPreferences.edit()?.remove(key)
+                                sharedPreferences.edit()?.putString(key, "on")?.apply()
+                            }
+                        }
+                    }
+                }
+                catch(_: ClassCastException) {}
+            }
         }
     }
 
     private fun applyUiMode() {
         val sharedPreferences = getDefaultSharedPreferences(this)
         val key = getString(R.string.preferences_uimode_key)
-        if (sharedPreferences?.contains(key) == false) {
-            val oldSharedPreferences = getSharedPreferences(getString(R.string.preferences_key), Context.MODE_PRIVATE)
-            oldSharedPreferences.getString(key, "").let {
-                when (it) {
-                    "ON" -> {
-                        sharedPreferences.edit()?.putBoolean(key, true)?.apply()
-                    }
-                    "OFF" -> {
-                        sharedPreferences.edit()?.putBoolean(key, false)?.apply()
-                    }
-                    else -> {}
-                }
-            }
-        }
 
-        sharedPreferences?.getBoolean(getString(R.string.preferences_uimode_key), false).let {
+        sharedPreferences?.getString(key, "system").let {
             when (it) {
-                false -> {
+                "off" -> {
                     if (AppCompatDelegate.getDefaultNightMode()!=AppCompatDelegate.MODE_NIGHT_NO) {
                         AppCompatDelegate.setDefaultNightMode(AppCompatDelegate.MODE_NIGHT_NO)
                         recreate()
                     }
                 }
-                true -> {
+                "on" -> {
                     if (AppCompatDelegate.getDefaultNightMode()!=AppCompatDelegate.MODE_NIGHT_YES) {
                         AppCompatDelegate.setDefaultNightMode(AppCompatDelegate.MODE_NIGHT_YES)
                         recreate()
                     }
                 }
-                /* "AUTO" -> {
-                    if (AppCompatDelegate.getDefaultNightMode()!=AppCompatDelegate.MODE_NIGHT_AUTO) {
-                        AppCompatDelegate.setDefaultNightMode(AppCompatDelegate.MODE_NIGHT_AUTO)
+                "system" -> {
+                    if (AppCompatDelegate.getDefaultNightMode()!=AppCompatDelegate.MODE_NIGHT_FOLLOW_SYSTEM) {
+                        AppCompatDelegate.setDefaultNightMode(AppCompatDelegate.MODE_NIGHT_FOLLOW_SYSTEM)
                         recreate()
                     }
-                } */
+                }
             }
         }
     }
@@ -292,7 +323,7 @@ class ReportListActivity : AppCompatActivity(), ReportActivityListener {
         val sharedPreferences: SharedPreferences? = getDefaultSharedPreferences(this)
         sharedPreferences?.getBoolean(getString(R.string.preferences_report_translate_key), false).let {
             when (it) {
-                false -> {
+                false, null -> {
                     Core.setLocale("")
                 }
                 true -> {
@@ -307,6 +338,7 @@ class ReportListActivity : AppCompatActivity(), ReportActivityListener {
                     if (Build.VERSION.SDK_INT >= 24) {
                         Resources.getSystem().configuration.locales.get(0)
                     } else {
+                        @Suppress("DEPRECATION")
                         Resources.getSystem().configuration.locale
                     }
                 } else {
@@ -327,6 +359,34 @@ class ReportListActivity : AppCompatActivity(), ReportActivityListener {
         }
     }
 
+    fun showReport(id: Int) {
+        intent.putExtra(Core.ARG_REPORT_ID, id)
+        if (twoPane) {
+            val fragment: ReportDetailFragment = ReportDetailFragment().apply {
+                arguments = Bundle().apply {
+                    putInt(Core.ARG_REPORT_ID, id)
+                }
+            }
+
+            supportFragmentManager
+                    .beginTransaction()
+                    .replace(R.id.report_detail_container, fragment)
+                    .commit()
+
+            disposable.add(reportModel.getReport(id)
+                    .subscribeOn(Schedulers.io())
+                    .observeOn(AndroidSchedulers.mainThread())
+                    .doOnSuccess {
+                        title = it.filename
+                    }.subscribe())
+        } else {
+            val intent = Intent(this@ReportListActivity, ReportDetailActivity::class.java)
+            intent.putExtra(Core.ARG_REPORT_ID, id)
+
+            startActivityForResult(intent, SHOW_REPORT_REQUEST)
+        }
+    }
+
     fun deleteReport(id: Int) {
         disposable.add(reportModel
                 .deleteReport(id)
@@ -334,6 +394,9 @@ class ReportListActivity : AppCompatActivity(), ReportActivityListener {
                 .observeOn(AndroidSchedulers.mainThread())
                 .subscribe())
 
+        if (intent.getIntExtra(Core.ARG_REPORT_ID, -1)==id) {
+            intent.putExtra(Core.ARG_REPORT_ID, -1)
+        }
         if (twoPane) {
             val fragment = supportFragmentManager.findFragmentById(R.id.report_detail_container)
             if (fragment != null && (fragment as ReportDetailFragment).id == id) {
@@ -352,33 +415,32 @@ class ReportListActivity : AppCompatActivity(), ReportActivityListener {
 
 
         menu?.findItem(R.id.action_subscribe)?.isEnabled=false
-        subscriptionManager.ready.observe(this, Observer {
-            if (menu?.findItem(R.id.action_subscribe)?.title!=getString(R.string.subscribed_text)) {
+        subscriptionManager.ready.observe(this) {
+            if (subscriptionManager.subscribed.value == false) {
                 menu?.findItem(R.id.action_subscribe)?.isEnabled = it
             }
-        })
+        }
 
-        subscriptionManager.subscribed.observe(this, Observer {
+        subscriptionManager.subscribed.observe(this) {
             if (it) {
-                //menu?.findItem(R.id.action_settings)?.isVisible=true
-                menu?.findItem(R.id.action_subscribe).let { item ->
-                    item?.isEnabled=true
-                    item?.title = getString(R.string.subscribed_text)
-
-                    item?.setOnMenuItemClickListener { _ ->
-                        val intent = Intent(Intent.ACTION_VIEW)
-                        intent.data = Uri.parse(getString(R.string.subscription_manage_url).replace('|', '&'))
-                        startActivity(intent)
-
-                        true
+                if (subscriptionManager.isLifetime.value == true) {
+                    menu?.findItem(R.id.action_subscribe).let { item ->
+                        item?.title = getString(R.string.subscribe_text)
+                        item?.isVisible = false
                     }
-                }
+                } else {
+                    menu?.findItem(R.id.action_subscribe).let { item ->
+                        item?.isEnabled = true
+                        item?.title = getString(R.string.subscribed_text)
 
-                if (!Core.thanked) {
-                    // Show thanks message
-                    Core.thanked=true
-                    val toast = Toast.makeText(applicationContext, R.string.thanks_text, Toast.LENGTH_SHORT)
-                    toast.show()
+                        item?.setOnMenuItemClickListener { _ ->
+                            val intent = Intent(Intent.ACTION_VIEW)
+                            intent.data = Uri.parse(getString(R.string.subscription_manage_url).replace('|', '&'))
+                            startActivity(intent)
+
+                            true
+                        }
+                    }
                 }
             } else {
                 menu?.findItem(R.id.action_subscribe).let { item ->
@@ -386,13 +448,13 @@ class ReportListActivity : AppCompatActivity(), ReportActivityListener {
 
                     item?.setOnMenuItemClickListener { _ ->
                         val intent = Intent(this, SubscribeActivity::class.java)
-                        startActivity(intent)
+                        startActivityForResult(intent, SUBSCRIBE_REQUEST)
 
                         true
                     }
                 }
             }
-        })
+        }
 
         menu?.findItem(R.id.action_about).let {
             it?.setOnMenuItemClickListener {
@@ -436,6 +498,17 @@ class ReportListActivity : AppCompatActivity(), ReportActivityListener {
                         }
                     }
                 }
+                SUBSCRIBE_REQUEST -> {
+                    Toast.makeText(applicationContext, R.string.thanks_text, Toast.LENGTH_SHORT).show()
+                }
+                SHOW_REPORT_REQUEST -> {
+                    if (resultData!=null) {
+                        val id = resultData.getIntExtra(Core.ARG_REPORT_ID, -1)
+                        if (id!=-1 && twoPane) {
+                            showReport(id)
+                        }
+                    }
+                }
             }
         }
     }
@@ -446,27 +519,32 @@ class ReportListActivity : AppCompatActivity(), ReportActivityListener {
 
     override fun onCreate(savedInstanceState: Bundle?) {
         super.onCreate(savedInstanceState)
-        setContentView(R.layout.activity_report_list)
+        activityReportListBinding = ActivityReportListBinding.inflate(layoutInflater)
+        helloLayoutBinding = HelloLayoutBinding.inflate(layoutInflater)
 
-        setSupportActionBar(tool_bar)
-        tool_bar.title = title
+
+        setContentView(activityReportListBinding.root)
+
+        setSupportActionBar(activityReportListBinding.toolBar)
+        activityReportListBinding.toolBar.title = title
+
+        updatePreferences()
 
         subscriptionManager = SubscriptionManager.getInstance(application)
         lifecycle.addObserver(subscriptionManager)
 
         setLocale()
-        subscriptionManager.subscribed.observe(this, Observer {
+        subscriptionManager.subscribed.observe(this) {
             if (it==true) {
                 applyUiMode()
                 setPrefLocale()
             }
-        })
+        }
 
         val viewModelFactory = Injection.provideViewModelFactory(this)
-        ViewModelProviders.of(this, viewModelFactory).get(ReportViewModel::class.java)
-        reportModel = ViewModelProviders.of(this, viewModelFactory).get(ReportViewModel::class.java)
+        reportModel = ViewModelProvider(this, viewModelFactory)[ReportViewModel::class.java]
 
-        add_button.setOnClickListener {
+        activityReportListBinding.addButton.setOnClickListener {
             if (Build.VERSION.SDK_INT >= 19) {
                 val intent = Intent(Intent.ACTION_OPEN_DOCUMENT)
 
@@ -504,12 +582,12 @@ class ReportListActivity : AppCompatActivity(), ReportActivityListener {
                 }
             }
         }
-
-        clear_btn.setOnClickListener {
+        activityReportListBinding.reportListLayout.clearBtn.setOnClickListener {
             disposable.add(reportModel.deleteAllReports()
                 .subscribeOn(Schedulers.io())
                 .observeOn(AndroidSchedulers.mainThread())
                 .subscribe {
+                    intent.putExtra(Core.ARG_REPORT_ID, -1)
                     if (twoPane) {
                         val fragment = supportFragmentManager.findFragmentById(R.id.report_detail_container)
                         if (fragment != null) {
@@ -528,10 +606,10 @@ class ReportListActivity : AppCompatActivity(), ReportActivityListener {
         // large-screen layouts (res/values-w900dp).
         // If this view is present, then the
         // activity should be in two-pane mode.
-        if (report_detail_container != null)
+        if (activityReportListBinding.reportListLayout.reportDetailContainer != null)
             twoPane = true
 
-        setupRecyclerView(report_list)
+         setupRecyclerView(activityReportListBinding.reportListLayout.reportList)
 
         onNewIntent(intent)
     }
@@ -544,7 +622,7 @@ class ReportListActivity : AppCompatActivity(), ReportActivityListener {
                 .observeOn(AndroidSchedulers.mainThread())
                 .subscribe {
                     reports = it
-                    setupRecyclerView(report_list)
+                    setupRecyclerView(activityReportListBinding.reportListLayout.reportList)
 
                     val rootLayout: FrameLayout = findViewById(R.id.frame_layout)
                     if (reports.isEmpty()) {
@@ -557,18 +635,22 @@ class ReportListActivity : AppCompatActivity(), ReportActivityListener {
                         if (!found)
                             View.inflate(this, R.layout.hello_layout, rootLayout)
 
-                        clear_btn.visibility = View.INVISIBLE
+                        activityReportListBinding.reportListLayout.clearBtn.visibility = View.INVISIBLE
                     } else {
                         for (i: Int in rootLayout.childCount downTo 1) {
                             if (rootLayout.getChildAt(i - 1).id == R.id.hello_layout)
                                 rootLayout.removeViewAt(i - 1)
                         }
-                        rootLayout.removeView(hello_layout)
-                        clear_btn.visibility = View.VISIBLE
+                        rootLayout.removeView(helloLayoutBinding.root)
+                        activityReportListBinding.reportListLayout.clearBtn.visibility = View.VISIBLE
 
 
                     }
                 })
+
+        if (twoPane && intent.getIntExtra(Core.ARG_REPORT_ID, -1)!=-1) {
+            showReport(intent.getIntExtra(Core.ARG_REPORT_ID, -1))
+        }
     }
 
     override fun onStop() {
@@ -579,43 +661,19 @@ class ReportListActivity : AppCompatActivity(), ReportActivityListener {
     }
 
     private fun setupRecyclerView(recyclerView: RecyclerView) {
-        recyclerView.adapter = ItemRecyclerViewAdapter(this, reports, twoPane)
+        recyclerView.adapter = ItemRecyclerViewAdapter()
         recyclerView.isNestedScrollingEnabled = false
+        recyclerView.adapter?.notifyDataSetChanged()
     }
 
-    class ItemRecyclerViewAdapter(private val parentActivity: ReportListActivity,
-                                         private val reports: List<Report>,
-                                         private val twoPane: Boolean) :
-            RecyclerView.Adapter<ItemRecyclerViewAdapter.ViewHolder>() {
-
-        private val onClickListener: View.OnClickListener
-
-        init {
-            onClickListener = View.OnClickListener {
-                val report: Report = it.tag as Report
-                if (twoPane) {
-                    val fragment: ReportDetailFragment = ReportDetailFragment().apply {
-                        arguments = Bundle().apply {
-                            putInt(ReportDetailFragment.ARG_REPORT_ID, report.id)
-                        }
-                    }
-                    parentActivity.supportFragmentManager
-                            .beginTransaction()
-                            .replace(R.id.report_detail_container, fragment)
-                            .commit()
-                } else {
-                    val intent = Intent(it.context, ReportDetailActivity::class.java).apply {
-                        putExtra(ReportDetailFragment.ARG_REPORT_ID, report.id)
-                    }
-                    it.context.startActivity(intent)
-                }
-            }
+    inner class ItemRecyclerViewAdapter : RecyclerView.Adapter<ItemRecyclerViewAdapter.ViewHolder>() {
+        private val onClickListener: View.OnClickListener = View.OnClickListener {
+            showReport((it.tag as Report).id)
         }
 
         override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): ViewHolder {
-            val view = LayoutInflater.from(parent.context)
-                    .inflate(R.layout.report_list_content, parent, false)
-            return ViewHolder(view)
+            val binding = ReportListContentBinding.inflate(layoutInflater, parent, false)
+            return ViewHolder(binding)
         }
 
         override fun onBindViewHolder(holder: ViewHolder, position: Int) {
@@ -629,23 +687,28 @@ class ReportListActivity : AppCompatActivity(), ReportActivityListener {
             }
         }
 
-        override fun getItemCount(): Int = reports.size
+        override fun getItemCount(): Int {
+            return reports.size
+        }
 
-        inner class ViewHolder(view: View) : RecyclerView.ViewHolder(view) {
-            val name: TextView = view.name_text
+        inner class ViewHolder(binding: ReportListContentBinding) : RecyclerView.ViewHolder(binding.root) {
+            val name: TextView = binding.nameText
             var id: Int = -1
 
             init {
-                view.delete_button.setOnClickListener {
+                binding.deleteButton.setOnClickListener {
                     if (id != -1)
-                        parentActivity.deleteReport(id)
+                        deleteReport(id)
                 }
             }
         }
     }
 
     companion object {
-        const val OPEN_FILE_REQUEST= 40
+        const val SHOW_REPORT_REQUEST = 20
+        const val SUBSCRIBE_REQUEST = 30
+        const val OPEN_FILE_REQUEST = 40
         const val READ_EXTERNAL_STORAGE_PERMISSION_REQUEST = 50
+        const val OPEN_INTENT_PROCESSED = "net.mediaarea.mediainfo.internal.tag.Intent.Processed"
     }
 }
