@@ -3,7 +3,7 @@
 //  MediaInfo
 //
 //  Created by Max Pozdeev on 07.02.12.
-//  Copyright 2012-2020 Jerome Martinez. All rights reserved.
+//  Copyright 2012-2024 MediaArea.net SARL. All rights reserved.
 //
 
 #import "MyWindowController.h"
@@ -15,15 +15,15 @@
 #define kEasyTabIndex 0
 #define kTreeTabIndex 1
 #define kTextTabIndex 2
-#define kHTMLTabIndex 3
-#define kCompareTabIndex 4
+#define kCompareTabIndex 3
+#define kHTMLTabIndex 4
 
 #define kApplicationMenuTag 10
 #define kSubscribeMenuItemTag 11
 #define kViewMenuTag 50
+#define kOptionsMenuTag 53
 #define kCompareMenuItemTag 51
 #define kAdvancedMenuItemTag 52
-#define kAdvancedMenuItemSeparatorTag 53
 
 NSString* TextKindToNSString(ViewMenu_Kind kind)
 {
@@ -35,7 +35,9 @@ NSString* TextKindToNSString(ViewMenu_Kind kind)
 		case Kind_CSV:			_ret = @"CSV"; break;
 		case Kind_JSON:			_ret = @"JSON"; break;
 		case Kind_Graph_Svg:		_ret = @"Graph_Svg"; break;
-		case Kind_MPEG7:		_ret = @"MPEG-7"; break;
+		case Kind_MPEG7_Strict:		_ret = @"MPEG-7_Strict"; break;
+		case Kind_MPEG7_Relaxed:	_ret = @"MPEG-7_Relaxed"; break;
+		case Kind_MPEG7_Extended:	_ret = @"MPEG-7_Extended"; break;
 		case Kind_PBCore:		_ret = @"PBCore"; break;
 		case Kind_PBCore2:		_ret = @"PBCore2"; break;
 		case Kind_EBUCore_1_5:	_ret = @"EBUCore_1.5"; break;
@@ -75,13 +77,16 @@ NSString* TextKindToNSString(ViewMenu_Kind kind)
 	[tabSelector setMenu:otherViewsMenu forSegment:tabSelector.segmentCount - 1];
 	_exportSavePanel = nil;
     fileSelectorIsHidden = NO;
+    footerButtonIsHidden = YES;
     subscriptionEnabled = NO;
 
     observers = [[NSMutableArray alloc] init];
 
+    [tabs setTranslatesAutoresizingMaskIntoConstraints:NO];
+
     if (@available(macOS 10.9, *)) {
         [subscribeButton setEnabled:YES forSegment:0];
-        if([[SubscriptionManager shared] subscriptionActive]) {
+        if([[SubscriptionManager shared] subscriptionActive] || YES) {
             [self enableSubscription];
 
              NSString* defaultView = [[NSUserDefaults standardUserDefaults] stringForKey:@"defaultView"];
@@ -102,8 +107,12 @@ NSString* TextKindToNSString(ViewMenu_Kind kind)
                 [self selectViewJSON:nil];
             else if ([defaultView isEqualToString:@"Graph_Svg"])
                 [self selectViewGraph_Svg:nil];
-            else if ([defaultView isEqualToString:@"MPEG-7"])
-                [self selectViewMPEG7:nil];
+            else if ([defaultView isEqualToString:@"MPEG-7_Strict"])
+                [self selectViewMPEG7_Strict:nil];
+            else if ([defaultView isEqualToString:@"MPEG-7_Relaxed"])
+                [self selectViewMPEG7_Relaxed:nil];
+            else if ([defaultView isEqualToString:@"MPEG-7_Extended"])
+                [self selectViewMPEG7_Extended:nil];
             else if ([defaultView isEqualToString:@"PBCore"])
                 [self selectViewPBCore:nil];
             else if ([defaultView isEqualToString:@"PBCore2"])
@@ -197,10 +206,7 @@ NSString* TextKindToNSString(ViewMenu_Kind kind)
         [comboBox setHidden:NO];
         [hline setHidden:NO];
 
-        NSRect frame = [tabs frame];
-        frame.size.height-=42;
-        [tabs setFrame:frame];
-
+        [tabsViewTopConstraint setConstant:42];
         fileSelectorIsHidden = NO;
     }
 }
@@ -210,18 +216,39 @@ NSString* TextKindToNSString(ViewMenu_Kind kind)
         [comboBox setHidden:YES];
         [hline setHidden:YES];
 
-        NSRect frame = [tabs frame];
-        frame.size.height+=42;
-        [tabs setFrame:frame];
-
+        [tabsViewTopConstraint setConstant:0];
         fileSelectorIsHidden = YES;
     }
 }
 
+-(void)showFooterButton {
+    if(footerButtonIsHidden) {
+        [footerButton setHidden:NO];
+
+        [tabsViewBottomConstraint setConstant:42];
+        footerButtonIsHidden = NO;
+    }
+}
+
+-(void)hideFooterButton {
+    if(!footerButtonIsHidden) {
+        [footerButton setHidden:YES];
+
+        [tabsViewBottomConstraint setConstant:0];
+        footerButtonIsHidden = YES;
+    }
+}
+
 -(IBAction)selectCompareTab:(id)sender {
     if (@available(macOS 10.9, *)) {
         [self hideFileSelector];
         [tabSelector setSelectedSegment:kCompareTabIndex];
+
+        if(mediaList) {
+            [compareView setFiles:mediaList];
+            [compareView reload];
+        }
+
         [tabs selectTabViewItemAtIndex:kCompareTabIndex];
     }
 }
@@ -229,12 +256,24 @@ NSString* TextKindToNSString(ViewMenu_Kind kind)
 -(IBAction)selectEasyTab:(id)sender {
     [self showFileSelector];
 	[tabSelector setSelectedSegment:kEasyTabIndex];
+
+    if(mediaList && selectedFileIndex < [mediaList count])
+        [self updateEasyTabWithFileAtIndex:selectedFileIndex];
+
 	[tabs selectTabViewItemAtIndex:kEasyTabIndex];
 }
 
 -(IBAction)selectTreeTab:(id)sender {
     [self showFileSelector];
 	[tabSelector setSelectedSegment:kTreeTabIndex];
+
+    if(mediaList) {
+        [treeView setFiles:mediaList];
+
+        if(selectedFileIndex < [mediaList count])
+            [treeView setIndex:selectedFileIndex];
+    }
+
 	[tabs selectTabViewItemAtIndex:kTreeTabIndex];
 }
 
@@ -246,6 +285,10 @@ NSString* TextKindToNSString(ViewMenu_Kind kind)
 		[self updateTextTabWithFileAtIndex:selectedFileIndex];
 	}
 	[tabSelector setSelectedSegment:kTextTabIndex];
+
+	if(mediaList && selectedFileIndex < [mediaList count])
+		[self updateTextTabWithFileAtIndex:selectedFileIndex];
+
 	[tabs selectTabViewItemAtIndex:kTextTabIndex];
 }
 
@@ -293,9 +336,19 @@ NSString* TextKindToNSString(ViewMenu_Kind kind)
 	[self _selectViewOFKind:Kind_JSON];
 }
 
--(IBAction)selectViewMPEG7:(id)sender
+-(IBAction)selectViewMPEG7_Strict:(id)sender
 {
-	[self _selectViewOFKind:Kind_MPEG7];
+	[self _selectViewOFKind:Kind_MPEG7_Strict];
+}
+
+-(IBAction)selectViewMPEG7_Relaxed:(id)sender
+{
+	[self _selectViewOFKind:Kind_MPEG7_Relaxed];
+}
+
+-(IBAction)selectViewMPEG7_Extended:(id)sender
+{
+	[self _selectViewOFKind:Kind_MPEG7_Extended];
 }
 
 -(IBAction)selectViewPBCore:(id)sender
@@ -408,7 +461,7 @@ NSString* TextKindToNSString(ViewMenu_Kind kind)
 
 	NSInteger tag = exportFormatButton.selectedTag;
 
-	if (tag == 4 || tag == 13 || tag == 14)
+	if (tag == 4 || tag == 15 || tag == 16)
 		[_exportSavePanel setAllowedFileTypes:@[@"json"]];
 	else if (tag == 5)
 		[_exportSavePanel setAllowedFileTypes:@[@"svg"]];
@@ -463,45 +516,51 @@ NSString* TextKindToNSString(ViewMenu_Kind kind)
 					format = TextKindToNSString(Kind_Graph_Svg);
 					break;
 				case 6:
-					format = TextKindToNSString(Kind_MPEG7);
+					format = TextKindToNSString(Kind_MPEG7_Strict);
 					break;
 				case 7:
-					format = TextKindToNSString(Kind_PBCore);
+					format = TextKindToNSString(Kind_MPEG7_Relaxed);
 					break;
 				case 8:
-					format = TextKindToNSString(Kind_PBCore2);
+					format = TextKindToNSString(Kind_MPEG7_Extended);
 					break;
 				case 9:
-					format = TextKindToNSString(Kind_EBUCore_1_5);
+					format = TextKindToNSString(Kind_PBCore);
 					break;
 				case 10:
-					format = TextKindToNSString(Kind_EBUCore_1_6);
+					format = TextKindToNSString(Kind_PBCore2);
 					break;
 				case 11:
-					format = TextKindToNSString(Kind_EBUCore_1_8_ps);
+					format = TextKindToNSString(Kind_EBUCore_1_5);
 					break;
 				case 12:
-					format = TextKindToNSString(Kind_EBUCore_1_8_sp);
+					format = TextKindToNSString(Kind_EBUCore_1_6);
 					break;
 				case 13:
-					format = TextKindToNSString(Kind_EBUCore_1_8_ps_json);
+					format = TextKindToNSString(Kind_EBUCore_1_8_ps);
 					break;
 				case 14:
-					format = TextKindToNSString(Kind_EBUCore_1_8_sp_json);
+					format = TextKindToNSString(Kind_EBUCore_1_8_sp);
 					break;
 				case 15:
-					format = TextKindToNSString(Kind_FIMS_1_1);
+					format = TextKindToNSString(Kind_EBUCore_1_8_ps_json);
 					break;
 				case 16:
-					format = TextKindToNSString(Kind_FIMS_1_2);
+					format = TextKindToNSString(Kind_EBUCore_1_8_sp_json);
 					break;
 				case 17:
-					format = TextKindToNSString(Kind_FIMS_1_3);
+					format = TextKindToNSString(Kind_FIMS_1_1);
 					break;
 				case 18:
-					format = TextKindToNSString(Kind_reVTMD);
+					format = TextKindToNSString(Kind_FIMS_1_2);
 					break;
 				case 19:
+					format = TextKindToNSString(Kind_FIMS_1_3);
+					break;
+				case 20:
+					format = TextKindToNSString(Kind_reVTMD);
+					break;
+				case 21:
 					format = TextKindToNSString(Kind_NISO_Z39_87);
 					break;
 				case 0:
@@ -548,12 +607,12 @@ NSString* TextKindToNSString(ViewMenu_Kind kind)
         if(view && view.submenu) {
             NSMenuItem *compare = [view.submenu itemWithTag:kCompareMenuItemTag];
             [compare setHidden:NO];
+        }
 
-            NSMenuItem *advanced = [view.submenu itemWithTag:kAdvancedMenuItemTag];
+        NSMenuItem *options = [menu itemWithTag:kOptionsMenuTag];
+        if(options && options.submenu) {
+            NSMenuItem *advanced = [options.submenu itemWithTag:kAdvancedMenuItemTag];
             [advanced setHidden:NO];
-
-            NSMenuItem *separator = [view.submenu itemWithTag:kAdvancedMenuItemSeparatorTag];
-            [separator setHidden:NO];
         }
     }
 
@@ -654,8 +713,12 @@ NSString* TextKindToNSString(ViewMenu_Kind kind)
 		}
 
 		[comboController setContent:array];
-		[compareView setFiles:mediaList];
-		[treeView setFiles:mediaList];
+
+		if ([tabs indexOfTabViewItem:tabs.selectedTabViewItem] == kCompareTabIndex)
+			[compareView setFiles:mediaList];
+
+		if ([tabs indexOfTabViewItem:tabs.selectedTabViewItem] == kTreeTabIndex)
+			[treeView setFiles:mediaList];
 
 		//display first added file
 		[self setSelectedFileIndex:oldCount];
@@ -666,24 +729,46 @@ NSString* TextKindToNSString(ViewMenu_Kind kind)
 
 -(void)showFileAtIndex:(NSUInteger)index {
 	// Easy view
-	[self updateEasyTabWithFileAtIndex:index];
+	if ([tabs indexOfTabViewItem:tabs.selectedTabViewItem] == kEasyTabIndex)
+		[self updateEasyTabWithFileAtIndex:index];
 
 	//Text View
-	[self updateTextTabWithFileAtIndex:index];
+	if ([tabs indexOfTabViewItem:tabs.selectedTabViewItem] == kTextTabIndex)
+		[self updateTextTabWithFileAtIndex:index];
 
-    //HTML View
-    [self updateHTMLTabWithFileAtIndex:index];
+	//HTML View
+	if ([tabs indexOfTabViewItem:tabs.selectedTabViewItem] == kHTMLTabIndex)
+		[self updateHTMLTabWithFileAtIndex:index];
 
 	//tree view
-	[treeView setIndex:index];
+	if ([tabs indexOfTabViewItem:tabs.selectedTabViewItem] == kTreeTabIndex)
+		[treeView setIndex:index];
 
 	// compare view
-	[compareView reload];
+	if ([tabs indexOfTabViewItem:tabs.selectedTabViewItem] == kCompareTabIndex)
+		[compareView reload];
 
 	//recent items
 	NSString *filename = [mediaList filenameAtIndex:index];
 	[[NSDocumentController sharedDocumentController] noteNewRecentDocumentURL:[NSURL fileURLWithPath:filename]];
 
+    // Conformance button
+    NSUInteger audioCount=[mediaList numberOFStreamsAtIndex:index ofStreamKind:oMediaInfoStream_Audio];
+    BOOL display=NO;
+    for (NSUInteger pos = 0; pos < audioCount; pos++)
+    {
+        if ([[mediaList GetAtIndex:index streamKind:oMediaInfoStream_Audio streamNumber:pos parameter:@"ConformanceErrors"] isNotEqualTo:@""] ||
+            [[mediaList GetAtIndex:index streamKind:oMediaInfoStream_Audio streamNumber:pos parameter:@"ConformanceWarnings"] isNotEqualTo:@""])
+        {
+            display=YES;
+            break;
+        }
+    }
+
+    if (display)
+        [self showFooterButton];
+    else
+        [self hideFooterButton];
 }
 
 
@@ -981,8 +1066,16 @@ NSString* TextKindToNSString(ViewMenu_Kind kind)
 		BOOL state = [tabs indexOfTabViewItem:tabs.selectedTabViewItem] == kTextTabIndex && _lastTextKind == Kind_Graph_Svg ? YES : NO;
 		[menuItem setState: (state ? NSOnState : NSOffState)];
 	}
-	else if(action == @selector(selectViewMPEG7:)) {
-		BOOL state = [tabs indexOfTabViewItem:tabs.selectedTabViewItem] == kTextTabIndex && _lastTextKind == Kind_MPEG7 ? YES : NO;
+	else if(action == @selector(selectViewMPEG7_Strict:)) {
+		BOOL state = [tabs indexOfTabViewItem:tabs.selectedTabViewItem] == kTextTabIndex && _lastTextKind == Kind_MPEG7_Strict ? YES : NO;
+		[menuItem setState: (state ? NSOnState : NSOffState)];
+	}
+	else if(action == @selector(selectViewMPEG7_Relaxed:)) {
+		BOOL state = [tabs indexOfTabViewItem:tabs.selectedTabViewItem] == kTextTabIndex && _lastTextKind == Kind_MPEG7_Relaxed ? YES : NO;
+		[menuItem setState: (state ? NSOnState : NSOffState)];
+	}
+	else if(action == @selector(selectViewMPEG7_Extended:)) {
+		BOOL state = [tabs indexOfTabViewItem:tabs.selectedTabViewItem] == kTextTabIndex && _lastTextKind == Kind_MPEG7_Extended ? YES : NO;
 		[menuItem setState: (state ? NSOnState : NSOffState)];
 	}
 	else if(action == @selector(selectViewPBCore:)) {
@@ -1153,4 +1246,25 @@ NSString* TextKindToNSString(ViewMenu_Kind kind)
         }
     }
 }
+
+-(IBAction)fullParse:(id)sender {
+    if([sender isKindOfClass: [NSMenuItem class]]) {
+        NSMenuItem* item = sender;
+
+        BOOL newState = !item.state;
+        [item setState:newState];
+
+        [oMediaInfoList setOptionStatic:@"ParseSpeed" withValue:(newState?@"1":@"0.5")];
+
+        if(mediaList && selectedFileIndex < [mediaList count]) {
+            [self showFileAtIndex:selectedFileIndex];
+        }
+    }
+}
+
+- (IBAction)showConformanceInfo:(id)sender {
+    NSString *URL = [mediaList getConformanceURLForIndex:selectedFileIndex];
+    [[NSWorkspace sharedWorkspace] openURL:[NSURL URLWithString:URL]];
+}
+
 @end
