@@ -7,10 +7,11 @@
 #include "translate.h"
 #include "about.h"
 #include "ui_about.h"
+#include <QCoreApplication>
 #include <QDesktopServices>
 #include <QUrl>
 
-About::About(const QString& version, QWidget *parent) :
+About::About(QWidget *parent) :
     QDialog(parent),
     ui(new Ui::About)
 {
@@ -20,7 +21,12 @@ About::About(const QString& version, QWidget *parent) :
     setWindowTitle("About");
 #endif
 
-    ui->aboutText->setText(ui->aboutText->text().replace("VERSION", version));
+#if defined(_WIN32) && defined(WINAPI_FAMILY) && (WINAPI_FAMILY==WINAPI_FAMILY_APP) // Remove donate button
+    ui->donate->setVisible(false);
+#endif
+
+    ui->logoMail->setPixmap(QIcon(":/icon/aboutmail.svg").pixmap(ui->logoMail->maximumSize()));
+    ui->aboutText->setText(ui->aboutText->text().arg(QCoreApplication::applicationVersion()));
 }
 
 About::~About()
