@@ -41,8 +41,9 @@ using namespace ZenLib;
 
 //---------------------------------------------------------------------------
 __fastcall TExportF::TExportF(TComponent* Owner)
-    : TForm(Owner)
+    : CloseDialog(true), TForm(Owner)
 {
+    OnCloseQuery=FormCloseQuery;
 }
 
 //---------------------------------------------------------------------------
@@ -83,7 +84,25 @@ void TExportF::Name_Adapt()
         SaveDialog1->DefaultExt=__T("xml");
         SaveDialog1->Filter=__T("XML File|*.xml");
     }
-    else if (Export->ActivePage==Export_MPEG7)
+    else if (Export->ActivePage==Export_JSON)
+    {
+        FN.Extension_Set(__T("json"));
+        SaveDialog1->DefaultExt=__T("json");
+        SaveDialog1->Filter=__T("JSON File|*.json");
+    }
+    else if (Export->ActivePage==Export_MPEG7_Strict)
+    {
+        FN.Extension_Set(__T("xml"));
+        SaveDialog1->DefaultExt=__T("xml");
+        SaveDialog1->Filter=__T("MPEG-7 File|*.xml");
+    }
+    else if (Export->ActivePage==Export_MPEG7_Relaxed)
+    {
+        FN.Extension_Set(__T("xml"));
+        SaveDialog1->DefaultExt=__T("xml");
+        SaveDialog1->Filter=__T("MPEG-7 File|*.xml");
+    }
+    else if (Export->ActivePage==Export_MPEG7_Extended)
     {
         FN.Extension_Set(__T("xml"));
         SaveDialog1->DefaultExt=__T("xml");
@@ -161,6 +180,18 @@ void TExportF::Name_Adapt()
         SaveDialog1->DefaultExt=__T("xml");
         SaveDialog1->Filter=__T("XML File|*.xml");
     }
+    else if (Export->ActivePage==Export_NISO_Z39_87)
+    {
+        FN.Extension_Set(__T("xml"));
+        SaveDialog1->DefaultExt=__T("xml");
+        SaveDialog1->Filter=__T("XML File|*.xml");
+    }
+    else if (Export->ActivePage==Export_Graph_Svg)
+    {
+        FN.Extension_Set(__T("svg"));
+        SaveDialog1->DefaultExt=__T("svg");
+        SaveDialog1->Filter=__T("SVG File|*.svg");
+    }
     else if (Export->ActivePage==Export_Custom)
     {
         if (Prefs->Details[Prefs_Custom](Stream_Max+2, 1).size()>0 && Prefs->Details[Prefs_Custom](Stream_Max+2, 1)[0]==__T('<')) //test if HTML
@@ -195,8 +226,16 @@ int TExportF::Run(MediaInfoNameSpace::MediaInfoList &MI, ZenLib::Ztring DefaultF
 
     if (Info==__T("XML"))
         Export->ActivePage=Export_XML;
-    else if (Info==__T("MPEG-7"))
-        Export->ActivePage=Export_MPEG7;
+    else if (Info==__T("MIXML"))
+        Export->ActivePage=Export_XML;
+    else if (Info==__T("JSON"))
+        Export->ActivePage=Export_JSON;
+    else if (Info==__T("MPEG-7_Strict"))
+        Export->ActivePage=Export_MPEG7_Strict;
+    else if (Info==__T("MPEG-7_Relaxed"))
+        Export->ActivePage=Export_MPEG7_Relaxed;
+    else if (Info==__T("MPEG-7_Extended"))
+        Export->ActivePage=Export_MPEG7_Extended;
     else if (Info==__T("PBCore_1.2"))
         Export->ActivePage=Export_PBCore;
     else if (Info==__T("PBCore_2.0"))
@@ -219,6 +258,10 @@ int TExportF::Run(MediaInfoNameSpace::MediaInfoList &MI, ZenLib::Ztring DefaultF
         Export->ActivePage=Export_FIMS_1_2;
     else if (Info==__T("FIMS_1.3"))
         Export->ActivePage=Export_FIMS_1_3;
+    else if (Info==__T("NISO_Z39.87"))
+        Export->ActivePage=Export_NISO_Z39_87;
+    else if (Info==__T("Graph_Svg"))
+        Export->ActivePage=Export_Graph_Svg;
     else if (Info==__T("reVTMD"))
         Export->ActivePage=Export_reVTMD;
 
@@ -446,7 +489,7 @@ void TExportF::Export_Run()
     }
     else if (Export->ActivePage==Export_XML)
     {
-        ToExport->Option_Static(__T("Inform"), __T("XML"));
+        ToExport->Option_Static(__T("Inform"), __T("MIXML"));
         if (Export_XML_SideCar->Checked)
         {
             for (size_t Pos=0; Pos<ToExport->Count_Get(); Pos++)
@@ -460,16 +503,66 @@ void TExportF::Export_Run()
         }
         Text=ToExport->Inform().c_str();
     }
-    else if (Export->ActivePage==Export_MPEG7)
+    else if (Export->ActivePage==Export_JSON)
     {
-        ToExport->Option_Static(__T("Inform"), __T("MPEG-7"));
-        if (Export_MPEG7_SideCar->Checked)
+        ToExport->Option_Static(__T("Inform"), __T("JSON"));
+        if (Export_JSON_SideCar->Checked)
         {
             for (size_t Pos=0; Pos<ToExport->Count_Get(); Pos++)
             {
                 Text=ToExport->Inform(Pos).c_str();
                 File F;
-                F.Create(Ztring(ToExport->Get(Pos, Stream_General, 0, __T("CompleteName")).c_str())+__T(".mpeg7.xml"));
+                F.Create(Ztring(ToExport->Get(Pos, Stream_General, 0, __T("CompleteName")).c_str())+__T(".mediainfo.json"));
+                F.Write(Text);
+            }
+            return;
+        }
+        Text=ToExport->Inform().c_str();
+    }
+    else if (Export->ActivePage==Export_MPEG7_Strict)
+    {
+        ToExport->Option_Static(__T("Inform"), __T("MPEG-7_Strict"));
+        if (Export_MPEG7_Strict_SideCar->Checked)
+        {
+            for (size_t Pos=0; Pos<ToExport->Count_Get(); Pos++)
+            {
+                Text=ToExport->Inform(Pos).c_str();
+                File F;
+                F.Create(Ztring(ToExport->Get(Pos, Stream_General, 0, __T("CompleteName")).c_str())+__T(".mpeg7_strict.xml"));
+                F.Write(Text);
+            }
+            return;
+        }
+        Text=ToExport->Inform().c_str();
+    }
+
+    else if (Export->ActivePage==Export_MPEG7_Relaxed)
+    {
+        ToExport->Option_Static(__T("Inform"), __T("MPEG-7_Relaxed"));
+        if (Export_MPEG7_Relaxed_SideCar->Checked)
+        {
+            for (size_t Pos=0; Pos<ToExport->Count_Get(); Pos++)
+            {
+                Text=ToExport->Inform(Pos).c_str();
+                File F;
+                F.Create(Ztring(ToExport->Get(Pos, Stream_General, 0, __T("CompleteName")).c_str())+__T(".mpeg7_relaxed.xml"));
+                F.Write(Text);
+            }
+            return;
+        }
+        Text=ToExport->Inform().c_str();
+    }
+
+    else if (Export->ActivePage==Export_MPEG7_Extended)
+    {
+        ToExport->Option_Static(__T("Inform"), __T("MPEG-7_Extended"));
+        if (Export_MPEG7_Extended_SideCar->Checked)
+        {
+            for (size_t Pos=0; Pos<ToExport->Count_Get(); Pos++)
+            {
+                Text=ToExport->Inform(Pos).c_str();
+                File F;
+                F.Create(Ztring(ToExport->Get(Pos, Stream_General, 0, __T("CompleteName")).c_str())+__T(".mpeg7_extended.xml"));
                 F.Write(Text);
             }
             return;
@@ -668,6 +761,38 @@ void TExportF::Export_Run()
         }
         Text=ToExport->Inform().c_str();
     }
+    else if (Export->ActivePage==Export_NISO_Z39_87)
+    {
+        ToExport->Option_Static(__T("Inform"), __T("NISO_Z39_87"));
+        if (Export_NISO_Z39_87_SideCar->Checked)
+        {
+            for (size_t Pos=0; Pos<ToExport->Count_Get(); Pos++)
+            {
+                Text=ToExport->Inform(Pos).c_str();
+                File F;
+                F.Create(Ztring(ToExport->Get(Pos, Stream_General, 0, __T("CompleteName")).c_str())+__T(".NISO_Z39_87.xml"));
+                F.Write(Text);
+            }
+            return;
+        }
+        Text=ToExport->Inform().c_str();
+    }
+    else if (Export->ActivePage==Export_Graph_Svg)
+    {
+        ToExport->Option_Static(__T("Inform"), __T("Graph_Svg"));
+        if (Export_Graph_Svg_SideCar->Checked)
+        {
+            for (size_t Pos=0; Pos<ToExport->Count_Get(); Pos++)
+            {
+                Text=ToExport->Inform(Pos).c_str();
+                File F;
+                F.Create(Ztring(ToExport->Get(Pos, Stream_General, 0, __T("CompleteName")).c_str())+__T(".Graph.svg"));
+                F.Write(Text);
+            }
+            return;
+        }
+        Text=ToExport->Inform().c_str();
+    }
     else if (Export->ActivePage==Export_Custom)
     {
         ToExport->Option_Static(__T("Inform"), Prefs->Details[Prefs_Custom].Read());
@@ -701,7 +826,17 @@ void TExportF::Export_Run()
         F.Write(Append_Separator);
     }
     else
+    {
+        if (File::Exists(ZEN_UNICODE(Name->Text)))
+        {
+            if (MessageBox(NULL, __T("File Already exists. Overwrite?"), __T("Overwrite?"), MB_YESNO)!=IDYES)
+            {
+                CloseDialog=false;
+                return;
+            }
+        }
         F.Create(ZEN_UNICODE(Name->Text));
+    }
     F.Write(Text);
 }
 //---------------------------------------------------------------------------
@@ -715,12 +850,33 @@ void __fastcall TExportF::ExportChange(TObject *Sender)
         File_Append->Visible=false;
         Name_Choose->Visible=Export_XML_SideCar->Checked?false:true;;
     }
-    else if (Export->ActivePage==Export_MPEG7)
+    else if (Export->ActivePage==Export_JSON)
     {
-        Export_MPEG7_SideCarClick(Sender);
+        Export_JSON_SideCarClick(Sender);
         File_Append->Checked=false;
         File_Append->Visible=false;
-        Name_Choose->Visible=Export_MPEG7_SideCar->Checked?false:true;;
+        Name_Choose->Visible=Export_JSON_SideCar->Checked?false:true;;
+    }
+    else if (Export->ActivePage==Export_MPEG7_Strict)
+    {
+        Export_MPEG7_Strict_SideCarClick(Sender);
+        File_Append->Checked=false;
+        File_Append->Visible=false;
+        Name_Choose->Visible=Export_MPEG7_Strict_SideCar->Checked?false:true;;
+    }
+    else if (Export->ActivePage==Export_MPEG7_Relaxed)
+    {
+        Export_MPEG7_Relaxed_SideCarClick(Sender);
+        File_Append->Checked=false;
+        File_Append->Visible=false;
+        Name_Choose->Visible=Export_MPEG7_Relaxed_SideCar->Checked?false:true;;
+    }
+    else if (Export->ActivePage==Export_MPEG7_Extended)
+    {
+        Export_MPEG7_Extended_SideCarClick(Sender);
+        File_Append->Checked=false;
+        File_Append->Visible=false;
+        Name_Choose->Visible=Export_MPEG7_Extended_SideCar->Checked?false:true;;
     }
     else if (Export->ActivePage==Export_PBCore)
     {
@@ -806,6 +962,20 @@ void __fastcall TExportF::ExportChange(TObject *Sender)
         File_Append->Visible=false;
         Name_Choose->Visible=Export_reVTMD_SideCar->Checked?false:true;;
     }
+    else if (Export->ActivePage==Export_NISO_Z39_87)
+    {
+        Export_NISO_Z39_87_SideCarClick(Sender);
+        File_Append->Checked=false;
+        File_Append->Visible=false;
+        Name_Choose->Visible=Export_NISO_Z39_87_SideCar->Checked?false:true;;
+    }
+    else if (Export->ActivePage==Export_Graph_Svg)
+    {
+        Export_Graph_Svg_SideCarClick(Sender);
+        File_Append->Checked=false;
+        File_Append->Visible=false;
+        Name_Choose->Visible=Export_Graph_Svg_SideCar->Checked?false:true;;
+    }
     else
     {
         File_Append->Visible=true;
@@ -820,6 +990,14 @@ void __fastcall TExportF::OKClick(TObject *Sender)
 {
     Export_Run();
 }
+
+//---------------------------------------------------------------------------
+void __fastcall TExportF::FormCloseQuery(TObject *Sender, bool &CanClose)
+{
+    CanClose=CloseDialog;
+    CloseDialog=true;
+}
+
 //---------------------------------------------------------------------------
 
 void TExportF::CSV_Stream_Change (TComboBox* Box, TLabel* Label, stream_t Stream)
@@ -864,9 +1042,27 @@ void __fastcall TExportF::Export_XML_SideCarClick(TObject *Sender)
 }
 //---------------------------------------------------------------------------
 
-void __fastcall TExportF::Export_MPEG7_SideCarClick(TObject *Sender)
+void __fastcall TExportF::Export_JSON_SideCarClick(TObject *Sender)
 {
-    Name_Choose->Visible=Export_MPEG7_SideCar->Checked?false:true;
+    Name_Choose->Visible=Export_JSON_SideCar->Checked?false:true;
+}
+//---------------------------------------------------------------------------
+
+void __fastcall TExportF::Export_MPEG7_Strict_SideCarClick(TObject *Sender)
+{
+    Name_Choose->Visible=Export_MPEG7_Strict_SideCar->Checked?false:true;
+}
+//---------------------------------------------------------------------------
+
+void __fastcall TExportF::Export_MPEG7_Relaxed_SideCarClick(TObject *Sender)
+{
+    Name_Choose->Visible=Export_MPEG7_Relaxed_SideCar->Checked?false:true;
+}
+//---------------------------------------------------------------------------
+
+void __fastcall TExportF::Export_MPEG7_Extended_SideCarClick(TObject *Sender)
+{
+    Name_Choose->Visible=Export_MPEG7_Extended_SideCar->Checked?false:true;
 }
 //---------------------------------------------------------------------------
 
@@ -940,6 +1136,19 @@ void __fastcall TExportF::Export_reVTMD_SideCarClick(TObject *Sender)
 {
     Name_Choose->Visible=Export_reVTMD_SideCar->Checked?false:true;
 }
+
+//---------------------------------------------------------------------------
+
+void __fastcall TExportF::Export_NISO_Z39_87_SideCarClick(TObject *Sender)
+{
+    Name_Choose->Visible=Export_NISO_Z39_87_SideCar->Checked?false:true;
+}
+//---------------------------------------------------------------------------
+
+void __fastcall TExportF::Export_Graph_Svg_SideCarClick(TObject *Sender)
+{
+    Name_Choose->Visible=Export_Graph_Svg_SideCar->Checked?false:true;
+}
 //---------------------------------------------------------------------------
 
 void TExportF::GUI_Configure()
