@@ -255,6 +255,23 @@ void __fastcall TMainF::GUI_Configure()
     //Toolbar
     ToolBar->Visible=M_Options_ShowToolBar->Checked;
 
+    // FFmpeg
+    #ifndef MEDIAINFOGUI_PLUGIN_NO
+    Ztring InstallFolder = Application->ExeName.c_str();
+    InstallFolder = InstallFolder.substr(0, InstallFolder.rfind(__T("\\")) + 1);
+
+    if (Prefs->Config(__T("EnableFfmpeg"), 1) == __T("1") && !File::Exists(InstallFolder + __T("\\Plugin\\FFmpeg\\version.txt"))) //Try to install plugin
+    {
+        TPluginF* P = new TPluginF(this, PLUGIN_FFMPEG);
+        if (P->Configure())
+            P->ShowModal();
+        delete P;
+
+        if (!File::Exists(InstallFolder + __T("\\Plugin\\FFmpeg\\version.txt")))
+            MessageBox(NULL, __T("An error occured, please download and install the plugin manually from the MediaInfo download page."), __T("Error"), MB_OK);
+    }
+    #endif
+
     //Translation
     Translate();
 
@@ -628,6 +645,9 @@ void __fastcall TMainF::Refresh(TTabSheet *Page)
         Page=this->Page->ActivePage;
     size_t FilesCount=I->Count_Get();
 
+    if (!Prefs->Config(__T("EnableFfmpeg")).empty())
+        I->Option_Static(__T("Enable_Ffmpeg"), Prefs->Config(__T("EnableFfmpeg")));
+
     //Easy
          if (Page==Page_Easy)
     {
